Todos los productos
Search
Centro de documentos

Elastic Compute Service:Instance logon credentials

Última actualización: Sep 02, 2026

Una instancia ECS no tiene una contraseña predeterminada. Si olvida su contraseña, puede reset. Si no establece un nombre de usuario al crear una instancia, el sistema asigna uno predeterminado.

Sistema operativo

Nombre de usuario predeterminado

Descripción

Linux

root

El superusuario del sistema operativo Linux.

Windows

Administrator

La cuenta de administrador del sistema operativo Windows.

Importante

El usuario root tiene permisos elevados, lo que representa un riesgo de seguridad si se utiliza directamente. Se recomienda usar la cuenta ecs-user y ejecutar el comando sudo para obtener privilegios de root temporalmente en operaciones sensibles.

2. Gestión de contraseñas

2.1 Restablecer una contraseña olvidada

El restablecimiento de contraseña en línea no requiere reiniciar la instancia. Se recomienda probar primero este método.

Restablecimiento en línea (sin reinicio)

Nota

El restablecimiento de contraseña en línea requiere que Cloud Assistant Agent esté instalado en la instancia. Para más información, consulte Check the status of Cloud Assistant Agent y Install the Cloud Assistant Agent.

  1. Vaya a la página ECS console - Instances, seleccione una región y un resource group, y luego localice la instancia objetivo.

  2. Siga las instrucciones a continuación para abrir el cuadro de diálogo Reset Password.

    image

  3. En el cuadro de diálogo Reset Password, configure los siguientes parámetros y haga clic en OK. Deje los demás parámetros con sus valores predeterminados.

    • New Password/Confirm Password: Introduzca una contraseña segura para la instancia. Una contraseña segura debe contener letras mayúsculas, letras minúsculas, dígitos y caracteres especiales.

    • Password Reset Method: Seleccione Online Password Reset.

      Importante

      Si no puede seleccionar Online Password Reset, utilice el método offline password reset (requires restart).

    Si el restablecimiento de contraseña fails, utilice el método offline password reset (requires restart).

Restablecimiento sin conexión (requiere reinicio)

Importante

El restablecimiento de contraseña sin conexión solo surte efecto después de reiniciar la instancia. Reiniciar la instancia puede interrumpir sus servicios. Se recomienda realizar esta acción fuera del horario pico.

  1. Vaya a la página ECS console - Instances, seleccione una región y un resource group, y luego localice la instancia objetivo.

  2. Siga las instrucciones a continuación para abrir el cuadro de diálogo Reset Password.

    image

  3. En el cuadro de diálogo Reset Password, configure los siguientes parámetros y haga clic en OK.

    • New Password/Confirm Password: Introduzca una contraseña segura para la instancia. Una contraseña segura debe contener letras mayúsculas, letras minúsculas, dígitos y caracteres especiales.

    • Password Reset Method: Seleccione Offline Password Reset.

  4. Restart the instance.

    El restablecimiento de contraseña solo surte efecto después de reiniciar la instancia. Para minimizar las interrupciones del servicio, realice el reinicio fuera del horario pico.

  5. Connect to and log on to the instance by using VNC.

    Un inicio de sesión exitoso mediante VNC indica que la contraseña se ha restablecido en el sistema operativo.

    Si logra iniciar sesión correctamente en la instancia mediante VNC pero no consigue iniciar sesión con herramientas como Workbench , significa que la contraseña se ha restablecido. El fallo de inicio de sesión podría deberse a un problema de configuración de SSH. Para solucionar problemas, consulte Troubleshoot connection issues for Linux instances .

2.2 Cambiar una contraseña

Se recomienda intentar primero el restablecimiento de contraseña en línea desde la consola.

Restablecimiento de contraseña en línea

Nota

El restablecimiento de contraseña en línea requiere que Cloud Assistant Agent esté instalado en la instancia. Para más información, consulte Check the status of Cloud Assistant Agent y Install the Cloud Assistant Agent.

  1. Vaya a la página ECS console - Instances, seleccione una región y un resource group, y luego localice la instancia objetivo.

  2. Según su versión de consola, abra el cuadro de diálogo Reset Password.

    image

  3. En el cuadro de diálogo Reset Password, configure los siguientes parámetros y haga clic en OK. Deje los demás parámetros con sus valores predeterminados.

    • New Password/Confirm Password: Introduzca una contraseña segura para la instancia. Una contraseña segura debe contener letras mayúsculas, letras minúsculas, dígitos y caracteres especiales.

    • Password Reset Method: Seleccione Online Password Reset.

      Importante

      Si no puede seleccionar Online Password Reset, manually change the password on the instance.

    Si el restablecimiento de contraseña fails, manually change the password on the instance.

Cambio manual de contraseña

Instancia Windows

El siguiente ejemplo utiliza una instancia Windows Server 2019:

  1. Log on to the Windows instance by using Workbench.

  2. Haga clic con el botón derecho en el icono de Inicio image.png, haga clic en Run, introduzca compmgmt.msc y presione Enter.

  3. En el panel de navegación izquierdo, elija Computer Management > Local Users and Groups > User.

  4. Haga clic con el botón derecho en el nombre del usuario cuya contraseña desea cambiar, por ejemplo Administrator, y luego haga clic en Set Password.

  5. En el cuadro de diálogo Set Password for Administrator, haga clic en Continue y luego introduzca una nueva contraseña en los campos New Password y Confirm.

    Importante

    Utilice una contraseña segura que contenga letras mayúsculas, letras minúsculas, dígitos y caracteres especiales.

  6. Haga clic en OK. Aparecerá un mensaje de confirmación que indica que la contraseña se ha cambiado.

Instancia Linux

El siguiente ejemplo utiliza una instancia Alibaba Cloud Linux 3:

  1. Log on to the Linux instance by using Workbench.

  2. Ejecute el siguiente comando:

    Reemplace <username> con el usuario cuya contraseña desea cambiar.
    sudo passwd <username>
  3. Introduzca la nueva contraseña y presione Enter. Vuelva a introducir la nueva contraseña y presione Enter nuevamente.

    Importante

    Utilice una contraseña segura que contenga letras mayúsculas, letras minúsculas, dígitos y caracteres especiales.

  4. Un cambio de contraseña exitoso devuelve el siguiente mensaje:

    passwd: all authentication tokens updated successfully.

2. Gestión de key pair

Al crear una instancia, puede adjuntar un key pair que haya created or imported en Alibaba Cloud para iniciar sesión. Si no adjunta un key pair al crear la instancia, debe attach a key pair to the instance.

Un key pair es una credencial de inicio de sesión segura que ayuda a proteger su instancia contra ataques de fuerza bruta y de diccionario. Consta de dos partes: una clave pública, que se almacena en la instancia, y una clave privada, que usted conserva. Para iniciar sesión en una instancia, debe proporcionar la clave privada para la autenticación.

Cómo funciona la autenticación por key pair

La siguiente figura muestra el proceso simplificado de autenticación por key pair de Secure Shell (SSH). Después de que un cliente envía una solicitud de inicio de sesión, el servidor cifra una cadena aleatoria con la clave pública. El cliente descifra esta cadena con la clave privada y la devuelve al servidor. Luego, el servidor autentica al cliente comparando ambas cadenas para verificar si coinciden.

image
Para usar un key pair con una instancia Windows, habilite el servicio SSH en la instancia. No es posible gestionar el key pair desde la consola.

2.1 Crear o importar un key pair

Consola

Crear un key pair

  1. Vaya a la página ECS console - Key Pairs. En la esquina superior izquierda, seleccione una región y un resource group.

    Las instancias ECS solo pueden adjuntarse a key pairs en la misma región.
  2. Haga clic en Create Key Pair. Establezca el método de creación en Auto-create.

  3. Haga clic en OK.

    Una vez creado el key pair, el navegador descarga automáticamente el archivo de clave privada (key_pair_name.pem) a su computadora local.

Importar un key pair

Métodos de cifrado compatibles para key pairs importados

  • rsa

  • dsa

  • ssh-rsa

  • ssh-dss

  • ecdsa

  1. Ver la clave pública a partir de una clave privada

    La máquina local es Linux o macOS

    Utilice el comando ssh-keygen para extraer y mostrar la clave pública desde un archivo de clave privada existente.

    es la ruta al archivo de clave privada, como /path_to_key_pair/my-key-pair.pem .
    ssh-keygen -y -f <path_to_key_pair>

    Se devuelve la clave pública:

    ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABA****+GF9q7rhc6vYrExwT4WU4fsaRcVXGV2Mg9RHex21hl1au77GkmnIgukBZjywlQOT4GDdsJy2nBOdJPrCEBIPxxxxxxxxxx/fctNuKjcmMMOA8YUT+sJKn3l7rCLkesE+S5880yNdRjBiiUy40kyr7Y+fqGVdSOHGMXZQPpkBtojcxxxxxxxxxxx/htEqGa/Jq4fH7bR6CYQ2XgH/hCap29Mdi/G5Tx1nbUKuIHdMWOPvjxxxxxxxxxx+lHtTGiAIRG1riyNRVC47ZEVCxxxxxx

    La máquina local es Windows

    Para ver la clave pública, realice lo siguiente:

    1. Inicie PuTTYgen.

    2. Haga clic en Load.

    3. Seleccione un archivo .ppk o .pem.

      PuTTYgen muestra la clave pública.

  2. Importar el key pair (clave pública)

    1. Vaya a la página ECS console - Key Pairs. En la esquina superior izquierda, seleccione una región.

      Las instancias ECS solo pueden adjuntarse a key pairs en la misma región.
    2. Haga clic en Create Key Pair. Establezca el método de creación en Import y proporcione la Public Key:.

    3. Haga clic en OK para completar la importación.

API

2.2 Adjuntar o reemplazar un key pair

Consola

Nota

Puede adjuntar, desvincular y reemplazar key pairs para instancias Linux desde la consola.

Adjuntar un key pair al crear una instancia

Cuando create an instance by using the custom launch template, establezca Logon Credential en Key Pair y luego seleccione un Key Pair existente.

Adjuntar o reemplazar un key pair

Importante
  • Adjuntar o reemplazar un key pair en la consola requiere reiniciar la instancia para que el cambio surta efecto. Un reinicio puede interrumpir los servicios en la instancia. Planifique el momento del reinicio en consecuencia.

  • Solo puede adjuntar un máximo de un key pair a una instancia desde la consola. Para adjuntar varios key pairs, manually attach them within the instance.

Adjuntar o reemplazar en la consola (requiere reinicio)

Vaya a la página ECS console - Instances. En la esquina superior izquierda, seleccione una región y un resource group. Localice la instancia ECS objetivo y siga las instrucciones a continuación:

En la columna Actions, haga clic en Bind Key Pair. Seleccione un key pair existente y haga clic en OK. El cambio surte efecto después de reiniciar la instancia.

image

Adjuntar manualmente en la instancia (sin reinicio)

  1. Generar un key pair

    Los pasos para generar un key pair varían según la herramienta. Esta sección utiliza la herramienta ssh-keygen como ejemplo.

    Introduzca el siguiente comando para generar un key pair.

    ssh-keygen -t rsa -b 2048 -f id_rsa

    Parámetros:

    • -t rsa: El tipo de clave es rsa.

    • -b 2048: La longitud de la clave es de 2048 bits.

    • -f id_rsa: El nombre de archivo y la ubicación de guardado para el key pair.

    El sistema le solicitará introducir una frase de contraseña. La frase de contraseña protege su clave privada. Establecer una frase de contraseña es una medida de seguridad recomendada. Si no necesita una frase de contraseña, presione Enter para continuar.

    Después de ejecutar el comando, se generan dos archivos en el directorio actual:

    • id_rsa: Su clave privada.

    • id_rsa.pub: Su clave pública.

    Importante

    Mantenga su clave privada segura. No la comparta con otros.

  2. Adjuntar la clave pública a la instancia

    Después de log on to the instance using Workbench, siga estos pasos.

    El procedimiento para adjuntar una clave pública para un usuario root es diferente al de un usuario no root. Elija el procedimiento según sus necesidades.

    Establecer la clave pública para el usuario root

    1. Crear el archivo de configuración authorized_keys.

      Si el directorio /root/.ssh o el archivo authorized_keys no existen, ejecute los siguientes comandos para crearlos.

      sudo mkdir /root/.ssh
      sudo touch /root/.ssh/authorized_keys
    2. Agregar la clave pública.

      Abra el archivo authorized_keys con un editor de texto, como Vim.

      sudo vim /root/.ssh/authorized_keys

      Pegue su clave pública en el archivo. Puede agregar varias claves públicas. Cada clave pública debe estar en una nueva línea. Cuando termine, guarde y cierre el archivo.

    3. Establecer permisos de archivo.

      SSH requiere configuraciones de permisos estrictas. Los permisos incorrectos provocarán fallos en el inicio de sesión SSH.

      Ejecute los siguientes comandos para establecer los permisos correctos.

      sudo chmod 700 /root/.ssh
      sudo chmod 600 /root/.ssh/authorized_keys

    Establecer la clave pública para un usuario no root

    1. Crear el archivo de configuración authorized_keys.

      Si el directorio /home/<username>/.ssh o el archivo authorized_keys no existen, ejecute los siguientes comandos para crearlos.

      En los comandos, <username> es el nombre de usuario al que desea adjuntar la clave pública.
      sudo mkdir /home/<username>/.ssh
      sudo touch /home/<username>/.ssh/authorized_keys
    2. Agregar la clave pública.

      Abra el archivo authorized_keys con un editor de texto, como Vim.

      sudo vim /home/<username>/.ssh/authorized_keys

      Pegue su clave pública en el archivo. Puede agregar varias claves públicas. Cada clave pública debe estar en una nueva línea. Cuando termine, guarde y cierre el archivo.

    3. Establecer permisos de archivo.

      SSH requiere configuraciones de permisos estrictas. Los permisos incorrectos provocarán fallos en el inicio de sesión SSH.

      Ejecute los siguientes comandos para establecer los permisos correctos.

      sudo chown -R <username>:<username> /home/<username>/.ssh
      sudo chmod 700 /home/<username>/.ssh
      sudo chmod 600 /home/<username>/.ssh/authorized_keys
  3. Habilitar la autenticación por clave pública para el servicio SSH

    Después de configurar la clave pública, debe habilitar la autenticación por clave pública SSH en el servidor. De lo contrario, el inicio de sesión basado en claves fallará.

    1. Realice una copia de seguridad del archivo de configuración SSH /etc/ssh/sshd_config.

      sudo cp /etc/ssh/sshd_config /etc/ssh/sshd_config.bak
    1. Utilice un editor de texto, como Vim, para abrir el archivo /etc/ssh/sshd_config. Busque el parámetro PubkeyAuthentication y establézcalo en yes. Esto habilita la autenticación por clave pública.

      sudo vim /etc/ssh/sshd_config
    2. Reinicie el servicio SSH para aplicar los cambios.

      Ejemplo para Alibaba Cloud Linux 3:

      sudo systemctl restart sshd
      En algunos sistemas operativos, como Ubuntu o Debian, el servicio SSH se denomina ssh en lugar de sshd . Ajuste el comando según sea necesario.
      Importante

      Si está conectado a la instancia mediante SSH, reiniciar el servicio puede desconectarlo. Podrá volver a conectarse después de que se reinicie el servicio.

API

Nota

Solo puede utilizar operaciones de API para adjuntar, reemplazar o desvincular key pairs en instancias Linux.

  • Establecer un key pair al crear una instancia: Al llamar a RunInstances para crear una instancia, establezca KeyPairName con el nombre del key pair.

  • Adjuntar o reemplazar un key pair: Llame a AttachKeyPair y especifique el nombre del key pair KeyPairName y los ID de instancia InstanceIds.

  • Desvincular un key pair: Llame a DetachKeyPair y especifique el nombre del key pair KeyPairName y los ID de instancia InstanceIds.

2.3 Desvincular un key pair

Importante

Si desvincula un key pair desde la consola, debe reiniciar la instancia para que el cambio surta efecto. El reinicio puede interrumpir los servicios en la instancia. Planifique el momento del reinicio en consecuencia.

Desvincular en la consola (requiere reinicio)

Vaya a la página ECS console - Instances. En la esquina superior izquierda, seleccione una región y un resource group. Localice la instancia ECS objetivo y siga las instrucciones a continuación:

En la columna Actions, haga clic en Unbind Key Pair y luego en Unbind. El cambio surte efecto después de reiniciar la instancia.

image

Desvincular manualmente en la instancia (sin reinicio)

Puede desvincular manualmente un key pair dentro de una instancia si elimina su clave pública del archivo authorized_keys. La ruta al archivo authorized_keys varía según el usuario:

  • usuario root: /root/.ssh/authorized_keys

  • usuario distinto de root: /home/<username>/.ssh/authorized_keys

    donde <username> es el nombre del usuario.

2.4 Eliminar un key pair

Consola

Importante

No es posible eliminar un key pair vinculado a una instancia.

  1. Vaya a la página ECS console - Key Pairs. En la esquina superior izquierda, seleccione una región y un resource group.

  2. Localice el key pair que desea eliminar. En la columna Actions, haga clic en Delete. Esta acción elimina el key pair.

API

Llame a DeleteKeyPairs y establezca KeyPairNames con la lista de nombres de los key pairs que desea eliminar.

3. Inicio de sesión remoto multiusuario

Para configurar varios usuarios en una instancia ECS, siga estos pasos para crear un usuario estándar y habilitar el acceso remoto.

Sistemas Linux

Log on to the instance using Workbench y cree un usuario de la siguiente manera:

  1. Crear un usuario

    Reemplace en el comando por el nombre del usuario que desea crear. Por ejemplo, para crear un usuario llamado exampleuser , ejecute sudo useradd -m exampleuser .
    sudo useradd -m <username>
  2. Establecer una contraseña o un key pair

    Vincular un key pair

    1. Genere un archivo de key pair en su computadora local.

      Importante

      Por seguridad, no use ssh-keygen para crear un key pair en la instancia. No guarde la clave privada generada en la instancia ECS a la que se conectará.

      Los pasos para generar un key pair varían según la herramienta. Esta sección utiliza la herramienta ssh-keygen como ejemplo.

      Introduzca el siguiente comando para generar un key pair.

      ssh-keygen -t rsa -b 2048 -f id_rsa

      Parámetros:

      • -t rsa: El tipo de clave es rsa.

      • -b 2048: La longitud de la clave es de 2048 bits.

      • -f id_rsa: El nombre del archivo y la ubicación donde se guarda el key pair.

      El sistema le solicitará introducir una frase de contraseña. La frase de contraseña protege su clave privada. Establecer una frase de contraseña es una medida de seguridad recomendada. Si no necesita una frase de contraseña, presione Enter para continuar.

      Una vez ejecutado el comando, se generan dos archivos en el directorio actual:

      • id_rsa: Su clave privada.

      • id_rsa.pub: Su clave pública.

      Importante

      Mantenga segura su clave privada. No la comparta con otras personas.

    2. Vincule la clave pública al usuario.

      1. Cree el archivo de configuración de authorized_keys.

        Si el directorio /home/<username>/.ssh o el archivo authorized_keys no existen, ejecute los siguientes comandos para crearlos.

        En los comandos, <username> es el nombre del usuario al que desea vincular la clave pública.
        sudo mkdir /home/<username>/.ssh
        sudo touch /home/<username>/.ssh/authorized_keys
      2. Agregue la clave pública.

        Abra el archivo authorized_keys con un editor de texto, como Vim.

        sudo vim /home/<username>/.ssh/authorized_keys

        Pegue su clave pública en el archivo. Puede agregar varias claves públicas. Cada clave pública debe estar en una línea nueva. Al finalizar, guarde y cierre el archivo.

      3. Configure los permisos del archivo.

        SSH requiere configuraciones de permisos estrictas. Unos permisos incorrectos provocarán fallos en el inicio de sesión SSH.

        Ejecute los siguientes comandos para establecer los permisos correctos.

        sudo chown -R <username>:<username> /home/<username>/.ssh
        sudo chmod 700 /home/<username>/.ssh
        sudo chmod 600 /home/<username>/.ssh/authorized_keys
    3. Habilite la autenticación por clave pública para el servicio SSH.

      Después de configurar la clave pública, debe habilitar la autenticación por clave pública SSH en el servidor. De lo contrario, el inicio de sesión basado en claves fallará.

      1. Realice una copia de seguridad del archivo de configuración SSH /etc/ssh/sshd_config.

        sudo cp /etc/ssh/sshd_config /etc/ssh/sshd_config.bak
      1. Utilice un editor de texto, como Vim, para abrir el archivo /etc/ssh/sshd_config. Localice el parámetro PubkeyAuthentication y establézcalo en yes. Esto habilita la autenticación por clave pública.

        sudo vim /etc/ssh/sshd_config
      2. Reinicie el servicio SSH para aplicar los cambios.

        Ejemplo para Alibaba Cloud Linux 3:

        sudo systemctl restart sshd
        En algunos sistemas operativos, como Ubuntu o Debian, el servicio SSH se denomina ssh en lugar de sshd . Ajuste el comando según sea necesario.
        Importante

        Si está conectado a la instancia mediante SSH, reiniciar el servicio puede desconectarlo. Podrá volver a conectarse una vez que el servicio se haya reiniciado.

    Establecer una contraseña

    Ejecute el siguiente comando:

    Reemplace <username> por el nombre del usuario cuya contraseña desea cambiar.
    sudo passwd <username>

    Introduzca la nueva contraseña y presione Enter. Vuelva a introducir la nueva contraseña y presione Enter.

    Una vez cambiada correctamente la contraseña, el sistema muestra un mensaje similar al siguiente:

    passwd: all authentication tokens updated successfully.
  3. (Verificación) Inicie sesión remotamente en la instancia ECS con la nueva cuenta de usuario.

Sistemas Windows

Importante

De forma predeterminada, los sistemas Windows admiten un máximo de dos conexiones remotas simultáneas a través del Protocolo de escritorio remoto (RDP). Para permitir que más de dos usuarios inicien sesión en una instancia Windows al mismo tiempo, debe utilizar Remote Desktop Services de Microsoft.

Log on to the instance using Workbench y realice los siguientes pasos:

  1. Crear un usuario

    1. Abra el Panel de control, busque User Accounts, y luego haga clic en Change account type.

    image

    1. En la página Manage Accounts, haga clic en Add a user account para ir a la página Add User.

    image

    1. En la página Add a user, siga las instrucciones en pantalla para establecer el nombre de usuario y la contraseña del nuevo usuario.

      Este ejemplo crea un usuario llamado exampleuser. Configure el User Name según sus necesidades.
    2. Haga clic en Next y luego en Complete. Se crea el nuevo usuario.

    image

  2. Agregue el nuevo usuario al grupo Remote Desktop Users

    Solo los usuarios del grupo Remote Desktop Users pueden iniciar sesión remotamente en la instancia.

    1. En el cuadro de búsqueda de la barra de tareas, busque Computer Management. Haga clic en Computer Management en los resultados de búsqueda para abrir la página Computer Management.

    image

    1. En System tools > Local Users and Groups > , localice el grupo Remote Desktop Users. Haga doble clic en él para abrir la página Remote Desktop Users Properties.

    image

    1. El procedimiento se muestra en la imagen.

      1. En la página Remote Desktop Users Properties, haga clic en Add.

      2. Introduzca el nombre del usuario que creó y luego haga clic en Check Names. El nombre completo del usuario se introduce automáticamente en el cuadro de texto.

      3. Haga clic en OK. En la página Remote Desktop Users Properties, haga clic en OK y luego en OK. El usuario se agrega al grupo de usuarios.

    image

  3. (Verificación) Inicie sesión remotamente en la instancia ECS con la nueva cuenta de usuario.

Preguntas frecuentes

P1: ¿Cuál es el nombre de inicio de sesión predeterminado o inicial para una instancia ECS?

  • Para instancias Linux: El valor predeterminado es root. Si configuró la instancia para usar ecs-user durante la creación, el nombre de inicio de sesión es ecs-user.

  • Para instancias Windows: El valor predeterminado es Administrator.

P2: ¿Cuál es la contraseña predeterminada o inicial para una instancia ECS?

Ninguna.

Por motivos de seguridad, Alibaba Cloud no establece una contraseña predeterminada o inicial para las instancias ECS. Si no estableció una contraseña al crear la instancia, consulte Reset a password (if you do not know or have forgotten the original password).

P3: ¿Cómo puedo ver la contraseña de la instancia?

Alibaba Cloud no almacena la contraseña de su instancia, por lo que no es posible consultarla.

P4: ¿Cómo recupero las credenciales si olvido mi nombre de inicio de sesión o contraseña?

Nombre de inicio de sesión olvidado: Utilice la función Reset Password para encontrar su nombre de inicio de sesión. El nombre de inicio de sesión que estableció al crear la instancia aparece en la parte superior del cuadro de diálogo Reset Instance Password.

Contraseña olvidada: Consulte Reset a password (if you do not know or have forgotten the original password).

P5: ¿Por qué falla el restablecimiento de contraseña en línea?

La mayoría de los fallos ocurren porque el software de seguridad en la instancia bloquea el comando de Cloud Assistant para cambiar la contraseña. Utilice un offline password reset en su lugar.

P6: ¿Cómo cambio entre "root" y "ecs-user"?

  • Cambio de root a ecs-user

    Solo puede establecer el nombre de inicio de sesión como ecs-user cuando create an instance with a custom configuration utilizando imágenes específicas de Linux.

    Una vez creada la instancia, no puede cambiar directamente el nombre de inicio de sesión a ecs-user. Sin embargo, puede lograr un resultado similar. Add a new user for remote login llamado ecs-user y luego otorgue a ese usuario permisos sudo.

  • Cambio de ecs-user a root

    Le recomendamos encarecidamente que continúe usando ecs-user y ejecute los comandos que requieren privilegios con sudo. No inicie sesión directamente como usuario root.

    Si debe cambiar al usuario root en una sesión activa, inicie sesión en la instancia como ecs-user y luego ejecute el comando sudo su para cambiar al usuario root.

Nota: Las funciones de la consola, como el restablecimiento de contraseña sin conexión y la vinculación de un key pair, solo se aplican al nombre de inicio de sesión establecido al crear la instancia.

P7: ¿Cómo puedo habilitar una instancia Linux para que admita tanto la autenticación por key pair SSH como por contraseña?

Modifique el archivo de configuración /etc/ssh/sshd_config del servicio SSH.

  • Habilitar la autenticación por key pair SSH (recomendado para mayor seguridad): Esto se controla mediante la opción PubkeyAuthentication. Establezca esta opción en yes para habilitar la autenticación por key pair. Después de cambiar la configuración, reinicie el servicio SSH en la instancia.

  • Habilitar la autenticación por contraseña SSH (no recomendado debido a menor seguridad): Esto se controla mediante la opción PasswordAuthentication. Establezca esta opción en yes para habilitar la autenticación por contraseña. Después de cambiar la configuración, reinicie el servicio SSH en la instancia.

P8: ¿Cómo configuro el nombre de inicio de sesión de ECS al crear una instancia con Terraform?

El nombre de inicio de sesión predeterminado para una instancia ECS lo determina su imagen. El valor predeterminado es root para Linux y Administrator para Windows. Cuando create an ECS instance using Terraform, puede usar el bloque image_options y el parámetro login_as_non_root para configurar un usuario de inicio de sesión distinto de root.

  • Parámetro: login_as_non_root (Boolean).

  • Valor: Establezca este parámetro en true.

  • Resultado: El nombre de inicio de sesión de la instancia cambia a ecs-user.